@@ -1,6 +1,6 @@
 import os
 import unittest
-from vortex.rules import gateway
+from tpv.rules import gateway
 from . import mock_galaxy
 
 
@@ -11,9 +11,9 @@ class TestMapperSample(unittest.TestCase):
         galaxy_app = mock_galaxy.App()
         job = mock_galaxy.Job()
         user = mock_galaxy.User('gargravarr', 'fairycake@vortex.org')
-        vortex_config = os.path.join(os.path.dirname(__file__), 'fixtures/mapping-sample.yml')
+        tpv_config = os.path.join(os.path.dirname(__file__), 'fixtures/mapping-sample.yml')
         gateway.ACTIVE_DESTINATION_MAPPER = None
-        return gateway.map_tool_to_destination(galaxy_app, job, tool, user, vortex_config_files=[vortex_config])
+        return gateway.map_tool_to_destination(galaxy_app, job, tool, user, tpv_config_files=[tpv_config])
 
     def test_map_sample_tool(self):
         tool = mock_galaxy.Tool('sometool')
